%define name    autofs
%define version 5.0.5
%define release %mkrel 2

Name:           %{name}
Version:        %{version}
Release:        %{release}
License:        GPL
Summary:        A tool for automatically mounting and unmounting filesystems
Group:          System/Kernel and hardware
URL:            ftp://ftp.kernel.org/pub/linux/daemons/autofs
Source0:        ftp://ftp.kernel.org/pub/linux/daemons/autofs/v5/autofs-%{version}.tar.bz2
Source1:        %{name}.init
# this one is needed for ldap support
Patch46:        autofs-5.0.4-link-with-kerberos-lib.patch
Patch102:       autofs-5.0.4-separate-config-files.patch
Patch103:       autofs-5.0.4-rename-configuration-file.patch
Conflicts:       kernel < 2.6.17
Requires(post): rpm-helper
Requires(preun):rpm-helper
BuildRequires:  openldap-devel
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  libsasl-devel
BuildRequires:  krb-devel
BuildRequires:  libxml2-devel
Conflicts:      autosmb
Buildroot:      %{_tmppath}/%{name}-%{version}

%description
autofs is a daemon which automatically mounts filesystems when you use
them, and unmounts them later when you are not using them.  This can
include network filesystems, CD-ROMs, floppies, and so forth.

%prep
%setup -q -n %{name}-%{version}
%patch46 -p 1
%patch102 -p 1
%patch103 -p 1

%build
autoreconf
%serverbuild
%configure2_5x --with-mapdir=%{_sysconfdir}/%{name} \
           --with-confdir=%{_sysconfdir}/%{name} \
           --with-sasl=yes
%make DONTSTRIP=1

mkdir examples
cp samples/ldap* examples
cp samples/autofs.schema examples

rm -f README.gentoo

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/autofs
mkdir -p %{buildroot}%{_mandir}/{man5,man8}
mkdir -p %{buildroot}%{_sysconfdir}

%make install INSTALLROOT=%{buildroot}

install -d -m 755 %{buildroot}%{_initrddir}
install -m 755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}

rm -f %{buildroot}%{_sysconfdir}/init.d/%{name}
rm -f %{buildroot}%{_mandir}/man8/autofs*

cat > README.urpmi <<EOF
Mandriva RPM specific notes

setup
-----
Configuration handling in Mandriva package differs from upstream one on several points:
- the automounts daemon configuration file is %{_sysconfdir}/autofs/autofs.conf
- the autofs service configuration file is %{_sysconfdir}/sysconfig/autofs
- the configuration directives in %{_sysconfdir}/autofs/autofs.conf don't have
  the 'DEFAULT_' prefix (for instance, DEFAULT_TIMEOUT is just TIMEOUT). This
  has recently been changed upstream in version 5.0.2 too, but given than 
  documentation still refers to old names

Upgrade
-------
Map files have been moved from %{_sysconfdir} to %{_sysconfdir}/autofs. Upgrade
procedure should handle the change automatically.
LDAP usage has changed between autofs 4 and 5. The LDAP schema used has now to
be configured explicitely in autofs configuration, so as to avoid useless
queries. As this can't be handled by package upgrade procedure, you'll have to
edit your configuration manually. See auto.master(5) for details.

EOF

# tune default configuration
perl -pi -e 's|^BROWSE_MODE="no"|BROWSE_MODE="yes"|' \
    %{buildroot}%{_sysconfdir}/autofs/autofs.conf
perl -pi \
    -e 's|^/misc\t|#/misc\t|;' \
    -e 's|^/net\t|#/net\t|;' \
    %{buildroot}%{_sysconfdir}/autofs/auto.master

%pre
if [ $1 != "0" ]; then
    # upgrade
    if [ ! -d %{_sysconfdir}/autofs ]; then
        # 4 -> 5 upgrade
        mkdir %{_sysconfdir}/autofs
        for file in %{_sysconfdir}/auto.{master,misc,net,smb}; do
            if [ -f "$file" ]; then
                mv $file* %{_sysconfdir}/autofs
            fi
        done
    fi
fi

%post
%_post_service autofs

%preun
%_preun_service autofs

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc INSTALL CHANGELOG CREDITS README* examples
%config(noreplace) %{_sysconfdir}/autofs
%config(noreplace) %{_sysconfdir}/sysconfig/autofs
%{_initrddir}/%{name}
%{_libdir}/%{name}
%{_sbindir}/automount
%{_mandir}/*/*


%changelog
* Mon Mar 15 2010 Oden Eriksson <oeriksson@mandriva.com> 5.0.5-2mdv2010.1
+ Revision: 520011
- rebuilt for 2010.1

* Thu Sep 10 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.5-1mdv2010.0
+ Revision: 437529
- new version

* Sat Jul 18 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-9mdv2010.0
+ Revision: 397062
- update to latest patchlevel

* Sat May 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-8mdv2010.0
+ Revision: 373838
- update to latest patch level

* Fri Apr 10 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-7mdv2009.1
+ Revision: 365743
-update to latest patch level
-honor USE_MISC_DEVICE setting in initscript

* Sat Mar 14 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-6mdv2009.1
+ Revision: 354885
- update to latest official patch level

* Mon Mar 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-5mdv2009.1
+ Revision: 353183
- update to latest official patch level
- apply custom patches after official ones, to keep them verbatim
- tune configuration through substitutions rather than patches

* Tue Mar 03 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-4mdv2009.1
+ Revision: 347905
- update to latest official patch level

* Sun Feb 01 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-3mdv2009.1
+ Revision: 336233
- re-enable kerberos lib flag, otherwise ldap plugin doesn't work
- fix segfault when looking for host (#47423)

* Fri Jan 30 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-2mdv2009.1
+ Revision: 335551
- drop sasl detection patch, uneeded anymore
- drop ldap detection patch, available upstream
- update to latest upstream patch level

* Wed Dec 03 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-1mdv2009.1
+ Revision: 309829
- new version
- rediff configuration files separation patch
- drop merged patches

* Tue Sep 09 2008 Olivier Thauvin <nanardon@mandriva.org> 5.0.3-7mdv2009.0
+ Revision: 282880
- convert requires kernel... to conflicts, then avoiding to require kernel in virtual system

* Wed Jul 02 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.3-6mdv2009.0
+ Revision: 230676
- no dependency on nfs-utils in package (automount is not nfs-specific)
- no dependency on nfs-common in initscript (automound doesn't requires it)
- update to latest official patch set
- fix init script dependencies

* Tue May 20 2008 Stefan van der Eijk <stefan@mandriva.org> 5.0.3-5mdv2009.0
+ Revision: 209577
- rebuild, give it annother shot...
- sync patches to fix expire issue

* Fri Jan 25 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.3-4mdv2008.1
+ Revision: 158131
- sync with latest upstream patches (fix #37107)

  + Olivier Blin <oblin@mandriva.com>
    - update to new upstream version of basedn-with-spaces fix

* Mon Jan 21 2008 Olivier Blin <oblin@mandriva.com> 5.0.3-2mdv2008.1
+ Revision: 155518
- fix parsing mount options with LDAP mounts (upstream patch)

* Tue Jan 15 2008 Olivier Blin <oblin@mandriva.com> 5.0.3-1mdv2008.1
+ Revision: 152545
- workaround upstream ldap-page-control check by adding -lpthread
- add upstream ldap-page-control-configure-fix patch
- rediff comment-default-master-map patch
- 5.0.3
- remove upstream 5.0.2 patches
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Nov 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-10mdv2008.1
+ Revision: 109442
- fix kerberos linking, and re-enable sasl support
- patch45: fix build without sasl

* Mon Nov 12 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-9mdv2008.1
+ Revision: 108335
- add libxml2-devel build dependency, but disable sasl build for now, as it breaks ldap module, and is known to be non-functional anyway
- add available upstream patches

* Tue Oct 09 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-8mdv2008.1
+ Revision: 96243
- soft dependency on ypbind in init script

* Mon Oct 01 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-7mdv2008.0
+ Revision: 94155
- don't deal with /etc/modules.conf, this file isn't used anymore

* Sat Sep 15 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-6mdv2008.0
+ Revision: 86323
- add a reference to README.urpmi in configuration files comments
- don't ship upstream init script man page
- more explicit description of differences with upstream configuration
- patch 103: ensure configuration file remains /etc/autofs/autofs.conf

* Tue Sep 11 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-5mdv2008.0
+ Revision: 84307
- re-enable sasl build

* Mon Sep 10 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-4mdv2008.0
+ Revision: 84274
- update to latest upstream patch set
- fix configuration file name to autofs.conf
- disable sasl support, as it doesn't build

* Mon Jul 30 2007 Andreas Hasenack <andreas@mandriva.com> 5.0.2-3mdv2008.0
+ Revision: 56585
- added digital signature for tarball
- really enable sasl build (we already buildrequire it)

* Thu Jul 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-2mdv2008.0
+ Revision: 53710
- build requires sasl-devel
- set default browse mode to reduce cpu usage (fix #31901)

* Thu Jul 05 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-1mdv2008.0
+ Revision: 48725
- new version
  drop patches 100, 101, 102 and 104 (merged upstream)
  rediff patch 102

* Wed Jul 04 2007 Andreas Hasenack <andreas@mandriva.com> 5.0.1-6mdv2008.0
+ Revision: 48210
- rebuild with new serverbuild macro (-fstack-protector-all)
- autoconf-2.5x is gone, use plain autoconf

* Thu Jun 07 2007 Anssi Hannula <anssi@mandriva.org> 5.0.1-5mdv2008.0
+ Revision: 36155
- rebuild with correct optflags


* Wed Feb 28 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-2mdv2007.0
+ Revision: 130155
- init script harmonization
- init script harmonization

* Tue Feb 20 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-1mdv2007.1
+ Revision: 122961
- fix release tag
- final 5.0.1 version

* Mon Feb 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc3.2mdv2007.1
+ Revision: 122733
- update to latest patch level
- fix init script indentation
  add condrestart and condreload actions

* Fri Jan 12 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc3.1mdv2007.1
+ Revision: 107864
- new version (should fix #28113)
  rediff configuration patches
  drop ldap fix patch (merged upstream)
- Import autofs

* Wed Sep 13 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc2.2mdv2007.0
- more dependencies in init script

* Tue Sep 05 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc2.1mdv2007.0
- new version
- fix reload function in initscript (#25128)
- changed README.mdv to README.urpmi
- add some notes about LDAP handling change

* Sat Sep 02 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.6mdv2007.0
- comment default master map entries
- soft dependencies against ldap in init script

* Tue Aug 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.5mdv2007.0
- buildrequires

* Tue Aug 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.4mdv2007.0
- more cautious file testing during upgrade (fix #24768)

* Sat Aug 26 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.3mdv2007.0
- fix ldap lookup when only a map name is given

* Sat Aug 26 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.2mdv2007.0
- fix prevention of stripping

* Fri Aug 25 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.1mdv2007.0
- new version
- handle 4.x -> 5.x configuration file location change
- add status option to init script

* Fri Jun 30 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.0-0.beta6.1mdv2007.0
- new version
- move configuration files in /etc/autofs
- drop patches 1 and 9 (merged upstream)
- drop patch 2, 3, 7 and 12 (useless or undesirable according to developpers)
- use -DDONTSTRIP instead of -DDEBUG to prevent stripping before installation

* Sat Apr 29 2006 Stefan van der Eijk <stefan@eijk.nu> 4.1.4-9mdk
- Rebuild for sparc

* Thu Jan 26 2006 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-8mdk
- multimount patch (Andrey Borzenkov <arvidjaar@mail.ru>)
- various fixes in init script (Quel Qun <kelk1@comcast.net>)
- more init script cleanup

* Thu Jan 19 2006 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-6mdk
- new custom initscript, with parallel init and timeout support
- move executable scripts from /etc to /usr/lib/autofs
- drop redundant portmap requires
- drop useless README files

* Mon Nov 14 2005 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-5mdk
- define -DLDAP_DEPRECATED (fix #19605)
- make sure -g and standard optimisation flags are used
- cleanup samples file in documentation
- don't mark scripts as executable (TODO: install them under /usr/lib/autofs)
- drop non-applied patches

* Fri Nov 04 2005 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-4mdk
- spec cleanup
- more macros

* Wed Aug 31 2005 Oden Eriksson <oeriksson@mandriva.com> 4.1.4-3mdk
- rebuilt against new openldap-2.3.6 libs
- misc rpmlint fixes

* Thu Jul 14 2005 Nicolas Lcureuil <neoclust@mandriva.org> 4.1.4-2mdk
- Fix conflicts
- preReq => Requires(pre)

* Mon May 23 2005 Stefan van der Eijk <stefan@eijk.nu> 4.1.4-1mdk
- 4.1.4
- start autofs after named (45 --> 60)
- rediffed patch 3 (auto-master)
- rediffed patch 4 (init-redhat-only) now only changes the runlevel config
- rediffed patch 8 (stripdash)
- remove patch 20 (bad_chdir) merged upstream
- remove patch 21 (mtab_lock) merged upstream
- remove patch 22 (non_block_ping) merged upstream
- disable patch 23 (replicated_server_select) more or less merged upstream
- rediffed patch 24 (signal-race-fix)
- disable patch 25 (sock-leak-fix) more or less merged upstream
- remove patch 26 (strict) merged upstream
- spec file cosmetics (%%mkrel, remove %%ver, no TODO file in doc, add auto.smb)

* Fri Feb 04 2005 Buchan Milne <bgmilne@linux-mandrake.com> 4.1.3-3mdk
- rebuild for ldap2.2_7

* Tue Nov 23 2004 Stefan van der Eijk <stefan@mandrake.org> 4.1.3-2mdk
- let autofs start after the ldap server

* Tue Nov 23 2004 Stefan van der Eijk <stefan@mandrake.org> 4.1.3-1mdk
- 4.1.3
- rediff patch 4
- add 4.1.3 patches

* Wed May 05 2004 Juan Quintela <quintela@mandrakesoft.com> 4.1.2-1mdk
- merge with redhat 4.1.2-2.
- actualize spec file.
- lots of patches included upstream or irrelevant.
- 4.1.2.

* Wed Apr 07 2004 Stefan van der Eijk <stefan@eijk.nu> 4.0.0-0.22mdk
- Patch18: ldapv3 patch from mc@suse.de
- Source1: replace with suse's ldapv3 enabled one
- from Michael Scherer : clean some requires

